@@ -9,11 +9,12 @@ Para.deriv <- function (
 		...)
 {
   type <- match.arg(type, c('slope','inflection'))
-  M <- resp$M
-  a = p[1]; b = p[2]; c = p[3]; d = p[4]; f = p[5]
+  if(is.null(newdata)) x <- scale01(seq(resp$range[1] - diff(resp$range), resp$range[2] + diff(resp$range), length.out=10000)) else x <- scale01(newdata, ...)  
   if(is.null(model)) model <- pick.model(resp, gam=FALSE, ...)
-  if(is.null(newdata)) x <- scale01(seq(resp$range[1], resp$range[2], length.out=10000)) else x <- scale01(newdata, ...)  
-
+  if(missing(p)) p <- resp$models[[model]]$par
+  a = p[1]; b = p[2]; c = p[3]; d = p[4]; f = p[5]
+  M <- resp$M
+  
   fv <- switch(model,
      'I'  = expression(M/(1 + exp(a))),
      'II' = expression(M/(1 + exp(a + b * x))),
@@ -45,8 +46,15 @@ Para.deriv <- function (
             },
       IV = c(optimize(fv3, c(0, optima), a,b,c,d, maximum=TRUE)$maximum, optimize(fv3, c(optima, 1), a,b,c,d, maximum=FALSE)$minimum),
       V  = c(optimize(fv3, c(0, optima), a,b,c,d, maximum=TRUE)$maximum, optimize(fv3, c(optima, 1), a,b,c,d, maximum=FALSE)$minimum),
-      VI = c(optimize(fv3, c(0, optima[1]), a,b,c,d, maximum=TRUE)$maximum, optimize(fv3, c(optima[1], pessima), a,b,c,d,maximum=FALSE)$minimum,optimize(fv3, c(pessima, optima[2]), a,b,c,d, maximum=TRUE)$maximum, optimize(fv3, c(optima[2],1), a,b,c,d, maximum=FALSE)$minimum),
-     VII = c(optimize(fv3, c(0, optima[1]), a,b,c,d,f, maximum=TRUE)$maximum, optimize(fv3, c(optima[1], pessima), a,b,c,d,f, maximum=FALSE)$minimum,optimize(fv3, c(pessima, optima[2]), a,b,c,d,f, maximum=TRUE)$maximum, optimize(fv3, c(optima[2],1), a,b,c,d,f, maximum=FALSE)$minimum)
+      VI = c(optimize(fv3, c(0, optima[1]), a,b,c,d, maximum=TRUE)$maximum, 
+             optimize(fv3, c(optima[1], pessima), a,b,c,d,maximum=FALSE)$minimum, 
+             optimize(fv3, c(pessima, optima[2]), a,b,c,d, maximum=TRUE)$maximum, 
+             optimize(fv3, c(optima[2], max(x)), a,b,c,d, maximum=FALSE)$minimum),
+
+      VII = c(optimize(fv3, c(0, optima[1]), a,b,c,d,f, maximum=TRUE)$maximum, 
+              optimize(fv3, c(optima[1], pessima), a,b,c,d,f, maximum=FALSE)$minimum, 
+              optimize(fv3, c(pessima, optima[2]), a,b,c,d,f, maximum=TRUE)$maximum, 
+              optimize(fv3, c(optima[2], max(x)), a,b,c,d,f, maximum=FALSE)$minimum)
    )
    out <- rescale01(out, resp$range)
 ## Filter true inflection points
